@@ -1,3 +1,16 @@
+/**
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
+ */
 package ch.qos.logback.access.jetty;
 
 import java.io.File;
@@ -202,7 +215,7 @@ public class RequestLogImpl extends ContextBase implements RequestLog,
     return aai.getAppender(name);
   }
 
-  public boolean isAttached(Appender appender) {
+  public boolean isAttached(Appender<AccessEvent> appender) {
     return aai.isAttached(appender);
   }
 
