@@ -1,17 +1,20 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * 
- * Copyright (C) 1999-2006, QOS.ch
- * 
- * This library is free software, you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
  */
-
 package ch.qos.logback.classic.util;
 
 import ch.qos.logback.classic.Level;
-import ch.qos.logback.classic.spi.LoggingEvent;
+import ch.qos.logback.classic.spi.ILoggingEvent;
 import ch.qos.logback.core.net.SyslogConstants;
 
 public class LevelToSyslogSeverity {
@@ -21,7 +24,7 @@ public class LevelToSyslogSeverity {
    * methods i.e TRACE, DEBUG, WARN, INFO and ERROR are converted.
    * 
    */
-  static public int convert(LoggingEvent event) {
+  static public int convert(ILoggingEvent event) {
 
     Level level = event.getLevel();
 
