@@ -1,3 +1,16 @@
+/**
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
+ */
 package ch.qos.logback.classic.turbo;
 
 import java.util.ArrayList;
@@ -6,7 +19,7 @@ import java.util.List;
 import org.slf4j.MDC;
 import org.slf4j.Marker;
 
-import ch.qos.logback.classic.ClassicGlobal;
+import ch.qos.logback.classic.ClassicConstants;
 import ch.qos.logback.classic.Level;
 import ch.qos.logback.classic.Logger;
 import ch.qos.logback.core.spi.FilterReply;
@@ -31,7 +44,7 @@ public class DebugUsersTurboFilter extends TurboFilter {
     if (!level.equals(Level.DEBUG)) {
       return FilterReply.NEUTRAL;
     } 
-    String user = MDC.get(ClassicGlobal.USER_MDC_KEY);
+    String user = MDC.get(ClassicConstants.USER_MDC_KEY);
     if (user != null && userList.contains(user)) {
       return FilterReply.ACCEPT;
     }
