@@ -1,11 +1,15 @@
 /**
- * Logback: the generic, reliable, fast and flexible logging framework.
- * 
- * Copyright (C) 2000-2008, QOS.ch
- * 
- * This library is free software, you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation.
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
  */
 package org.slf4j.impl;
 
@@ -17,12 +21,12 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import ch.qos.logback.classic.PatternLayout;
-import ch.qos.logback.classic.spi.LoggingEvent;
+import ch.qos.logback.classic.spi.ILoggingEvent;
 import ch.qos.logback.core.AppenderBase;
 
-public class RecursiveLBAppender extends AppenderBase<LoggingEvent> {
+public class RecursiveLBAppender extends AppenderBase<ILoggingEvent> {
 
-  public List<LoggingEvent> list = new ArrayList<LoggingEvent>();
+  public List<ILoggingEvent> list = new ArrayList<ILoggingEvent>();
   public List<String> stringList = new ArrayList<String>();
   
   PatternLayout layout;
@@ -43,7 +47,7 @@ public class RecursiveLBAppender extends AppenderBase<LoggingEvent> {
     super.start();
   }
   
-  protected void append(LoggingEvent e) {
+  protected void append(ILoggingEvent e) {
     list.add(e);
     if(layout != null) {
       String s = layout.doLayout(e);
